@@ -122,6 +122,7 @@ def create_qlr(filename, fileqlr="", cmapname=None):
             if "type" not in metadata:
                 metadata["type"] = "viridis"
             cmapname = cmapname if cmapname else metadata["type"]
+            fieldname = cmapname
 
             filetpl = pkg_resources.resource_filename(__name__, "data/raster.qlr")
             if cmapname == "dtm":  # dtm
@@ -215,6 +216,10 @@ def create_qlr(filename, fileqlr="", cmapname=None):
                 metadata.update({"um": "m³"})
                 filetpl = pkg_resources.resource_filename(__name__, f"data/{cmapname}.qlr")
                 fill_color = "#127db9"
+            elif cmapname == "riverevent":
+                metadata.update({"um": "m³"})
+                filetpl = pkg_resources.resource_filename(__name__, f"data/{cmapname}.qlr")
+                fill_color = "#ff7db9"
             elif cmapname == "rain":
                 metadata.update({"um": "mm"})
                 filetpl = pkg_resources.resource_filename(__name__, f"data/{cmapname}.qlr")
